@@ -12,16 +12,17 @@ from typing import Union
 from astropy.io import fits
 from astropy.io.fits.hdu.hdulist import HDUList
 from dkist_fits_specifications.spec214 import expand_index_d
-from dkist_fits_specifications.spec214 import expand_index_k
 from dkist_fits_specifications.spec214 import level0
 from dkist_fits_specifications.spec214 import load_expanded_spec214
-from dkist_fits_specifications.spec214 import load_full_spec214
 from dkist_fits_specifications.utils import expand_naxis
 
 
 logger = logging.getLogger(__name__)
 
-__all__ = ["translate_spec122_to_spec214_l0", "translate_spec122_to_spec214"]
+__all__ = [
+    "translate_spec122_to_spec214_l0",
+    "sanitize_to_spec214_level1",
+]
 
 type_map = {"int": int, "float": float, "str": str, "bool": bool}
 
@@ -39,38 +40,6 @@ def translate_spec122_to_spec214_l0(
     output_headers = _add_214_l0_headers(input_headers)
     # update DATE keyword
     output_headers["DATE"] = datetime.now().isoformat()
-    # remove BZERO and BSCALE keywords- we don't use these anymore
-    try:
-        del output_headers["BZERO"]
-        del output_headers["BSCALE"]
-    except KeyError:
-        # if they aren't there we can't delete them
-        pass
-    if input_data:  # return hdu list if the input had data
-        return _format_output_hdu(output_headers, input_data)
-    return output_headers  # return headers if only headers were given
-
-
-def translate_spec122_to_spec214(
-    spec122_input: Union[HDUList, dict, fits.header.Header, str, IO, List]
-) -> Union[dict, HDUList]:
-    """
-    Convert spec 122 headers to spec 214 l0 headers
-    :param spec122_input: Spec 122 headers or headers + data to convert
-    """
-    # extract headers and data
-    input_headers, input_data = _parse_fits_like_input(spec122_input)
-    # convert headers
-    output_headers = _add_214_headers(input_headers)
-    # update DATE keyword
-    output_headers["DATE"] = datetime.now().isoformat()
-    # remove BZERO and BSCALE keywords- we don't use these anymore
-    try:
-        del output_headers["BZERO"]
-        del output_headers["BSCALE"]
-    except KeyError:
-        # if they aren't there we can't delete them
-        pass
     if input_data:  # return hdu list if the input had data
         return _format_output_hdu(output_headers, input_data)
     return output_headers  # return headers if only headers were given
@@ -90,7 +59,7 @@ def sanitize_to_spec214_level1(
         if keyword not in all_214_keys:
             header.remove(keyword)
 
-    if input_data:  # return hdu list if the input had data
+    if input_data is not None:  # return hdu list if the input had data
         return _format_output_hdu(header, input_data)
     return header  # return headers if only headers were given
 
@@ -128,9 +97,6 @@ def _format_output_hdu(hdr, data) -> HDUList:
     return hdu_list
 
 
-# generic_spec214_schema = level0.load_level0_spec214().values()
-
-
 def _create_spec214_schema_for_header(
     hdr: dict, generic_schema, naxis=None
 ) -> Dict[str, Dict[str, Any]]:
@@ -160,24 +126,6 @@ def _add_214_l0_headers(hdr: dict):
     return result
 
 
-def _add_214_headers(hdr: dict):
-    """
-    Adds new 214 headers into dictionary
-    """
-    result = {}  # output headers
-    generic_spec214_schema = load_full_spec214().values()
-    spec214_schema = _create_spec214_schema_for_header(hdr, generic_spec214_schema, hdr["NAXIS"])
-
-    # translate 122 -> 214 headers
-    for key, key_schema in spec214_schema.items():
-        result.update(_translate_key(key, key_schema, hdr))
-
-    # add remaining header values to result
-    hdr_keys_not_translated = {k: v for k, v in hdr.items() if k not in result}
-    result.update(hdr_keys_not_translated)
-    return result
-
-
 def _translate_key(key, key_schema, hdr) -> dict:
     default_values = {"str": "default", "int": -999, "float": -999.9, "bool": False}
     key_is_copied = key_schema.get("copy")
